# Local connection

OEF compatible local connection for testing purposes only.

## Usage

OEF compatible connection to be used for testing, does not interact with external nodes. Does not preserve state on restart.
